@@ -13,15 +13,20 @@
 rm -rf julius*
 tar xzvf $1
 ln -s julius-* julius
+rm -rf include/sent include/julius
 
 # update binaries
 cd julius
-./support/build-all.sh
-mv build-bin/* ../bin
+sh ./support/build-all.sh
+mv build/bin/* ../bin
+mv build/lib/* ../lib
+mv build/include/* ../include
+mv julius-simple/julius-simple.c ../julius-simple
 cd ..
 
 # copy the documents
-cp -p julius/00readme* .
+cp -p julius/00readme.txt 00readme-julius.txt
+cp -p julius/00readme-ja.txt 00readme-julius-ja.txt
 cp -p julius/LICENSE.txt .
 cp -p julius/Release* .
 cp -p julius/Sample*jconf* .
@@ -31,8 +36,12 @@ cp -p julius/gramtools/00readme-ja.txt doc/gramtools-ja.txt
 # copy manuals
 find julius/ -name "*.man" -exec ./support/cpman.sh {} \;
 find julius/ -name "*.man.ja" -exec ./support/cpmanja.sh {} \;
-qkc -m doc/catman/*
-qkc -s -m doc/catman.ja/*
+mv doc/man/*.1 doc/man/man1
+mv doc/man/man1/jconf.1 doc/man/man5/jconf.5
+mv doc/man.ja/*.1 doc/man.ja/man1
+mv doc/man.ja/man1/jconf.1 doc/man.ja/man5/jconf.5
+qkc -m doc/txt/*
+qkc -s -m doc/txt.ja/*
 
 # finished
 echo '#### FINISHED, you should remove julius* manually ###'
