@@ -5,10 +5,10 @@ dir=`dirname $1`
 cp $1 doc/man.ja/${base}.1
 
 if [ -f ${dir}/00readme-ja.txt ]; then
-    cp ${dir}/00readme-ja.txt doc/catman.ja/${base}.txt
+    cp ${dir}/00readme-ja.txt doc/txt.ja/${base}.txt
 fi
 if [ -f ${dir}/00readme-${base}-ja.txt ]; then
-    cp ${dir}/00readme-${base}-ja.txt doc/catman.ja/${base}.txt
+    cp ${dir}/00readme-${base}-ja.txt doc/txt.ja/${base}.txt
 fi
 
 echo $1
